UNIT Chfunzip;
{
Simple Delphi Component for UNZIP
 * by Dr Abimbola Olowofoyeku (The African Chief)
 Homepage: http://ourworld.compuserve.com/homepages/African_Chief

 * TMT Pascal port by Vadim Bodrov, TMT Development Corporation
 Homepage: http://www.tmt.com
}

{$I unzip.Inc}

{.$define UseDLL}   { /// uncomment this line to use the DLL /// }

INTERFACE
USES
{$ifdef Delphi}
Classes,
{$endif Delphi}
{$ifdef UseDLL}
zipinter,
{$else UseDLL}
unzip,
{$endif UseDLL}
ziptypes;

TYPE
{$ifndef __TMT__}
TChiefUnzip = {$ifdef ver70}OBJECT{$else}CLASS{$ifdef Delphi} ( TComponent ) {$endif}{$endif}
{$else}
TChiefUnzip = OBJECT
{$endif}
   PRIVATE
      FName,                         {source ZIP file name}
      FDir,                          {target directory}
      FSpec : String;                {file specifications to process in ZIP file}
      FReport : UnzipReportProc;     {points to callback procedure}
      FQuestion : UnzipQuestionProc; {points to callback procedure}
      CompSize : longint;            {compressed size}
      fNoRecurse : Boolean;          {whether to recurse into dirs}

  PUBLIC
   CONSTRUCTOR Create{$ifdef Delphi} ( aOwner : TComponent );override{$endif};
{$ifndef __TMT__}
   DESTRUCTOR  Destroy;{$ifdef ver70}virtual;{$else}override;{$endif}
{$else}
   DESTRUCTOR  Destroy; virtual;
{$endif}
   FUNCTION    Unzip : integer;virtual;  {unzip the archive}
   FUNCTION    View : integer;virtual;   {view the archive;must provide callback procedure}
   FUNCTION    Size : longint;virtual;   {uncompressed size of the archive}
   FUNCTION    CompressedSize : longint; virtual; {compressed size}

   PROCEDURE   SetFileName ( CONST aName : String ); virtual;
   PROCEDURE   SetDirectoryName ( CONST aName : String ); virtual;
   PROCEDURE   SetFileSpecs ( CONST Spec : String ); virtual;
   PROCEDURE   SetReportProc ( aProc : UnzipReportProc ); virtual;
   PROCEDURE   SetQuestionProc ( aProc : UnzipQuestionProc ); virtual;
   PROCEDURE   SetNoRecurse ( aRecurse : Boolean ); virtual;

  {$ifdef Delphi}
   PROPERTY      ReportProc : UnzipReportProc     Read FReport Write SetReportProc;
   PROPERTY      QuestionProc : UnzipQuestionProc Read FQuestion Write SetQuestionProc;
  PUBLISHED
   PROPERTY      FileName : String        Read FName      Write SetFileName;
   PROPERTY      DirectoryName : String   Read FDir       Write SetDirectoryName;
   PROPERTY      FileSpecs : string       Read FSpec      Write SetFileSpecs;
   PROPERTY      DontRecurse : boolean    Read FNoRecurse Write SetNoRecurse;
  {$endif Delphi}
END;

{$ifdef Delphi}
PROCEDURE Register;
{$endif Delphi}

{/////////////////////////////////////////////////////}
IMPLEMENTATION
{/////////////////////////////////////////////////////}
{$ifdef Delphi}
PROCEDURE Register;
BEGIN
   RegisterComponents ( 'Unzip', [ TChiefUnZip ] );
END;
{$endif Delphi}


CONSTRUCTOR TChiefUnzip.Create;
BEGIN
{$ifndef __TMT__}
  {$ifndef ver70}INHERITED Create{$Ifdef Delphi} ( aOwner ) {$endif Delphi};{$endif ver70}
{$endif}
  CompSize := 0;
  FName := '';
  FDir  := '';
  FSpec := '*.*';       { default to all files }
  FReport := NIL;       { no report callback }
  FQuestion := NIL;     { no question callback }
  fNoRecurse := FALSE;  { default to full recursion }
END;

DESTRUCTOR  TChiefUnzip.Destroy;
BEGIN
  SetUnZipReportProc ( NIL );
  SetUnZipQuestionProc ( NIL );
  SetNoRecurseDirs ( FALSE );   {reset recursion flag to default}
{$ifndef __TMT__}
  {$ifndef ver70}INHERITED Destroy;{$endif}
{$endif}
END;

FUNCTION    TChiefUnzip.Unzip : integer;
BEGIN
  Unzip := unzip_MissingParameter; {no zipfilename or target directory}
  IF ( FName = '' ) OR ( FDir = '' ) THEN exit;
  SetNoRecurseDirs ( fNoRecurse );   {set recursion flag}
  Unzip := FileUnzip ( @FName [ 1 ], @FDir [ 1 ], @FSpec [ 1 ], FReport, FQuestion );
END;

FUNCTION    TChiefUnzip.View : integer;
BEGIN
  View := unzip_MissingParameter;
  IF ( FName = '' ) OR ( @FReport = NIL ) THEN exit;
  View := ViewZip ( @FName [ 1 ], @FSpec [ 1 ], FReport );
END;

FUNCTION    TChiefUnzip.Size;
BEGIN
  Size := UnZipSize ( @FName [ 1 ], Compsize );
END;

FUNCTION    TChiefUnzip.CompressedSize;
BEGIN
  CompressedSize := CompSize;
END;

PROCEDURE   TChiefUnzip.SetFileName ( CONST aName : String );
BEGIN
   FName := aName + #0;
END;

PROCEDURE   TChiefUnzip.SetDirectoryName ( CONST aName : String );
BEGIN
    FDir := aName + #0;
END;

PROCEDURE   TChiefUnzip.SetFileSpecs ( CONST Spec : String );
BEGIN
    FSpec := Spec + #0;
END;

PROCEDURE   TChiefUnzip.SetReportProc ( aProc : UnzipReportProc );
BEGIN
   FReport := aProc;
END;

PROCEDURE   TChiefUnzip.SetQuestionProc ( aProc : UnzipQuestionProc );
BEGIN
   FQuestion := aProc;
END;

PROCEDURE   TChiefUnzip.SetNoRecurse ( aRecurse : Boolean );
BEGIN
   FNoRecurse := aRecurse;
END;

END.
